require(xlsx)
require(stringr)
require(dplyr)
require(tidyr)
require(PMCMR)

getwd()
setwd("/Users/leldite/-EDUCATION/PhD/Analysis 1/Daten/Boden")

humus_historic_long <- read.csv2("Data_OLayer_Supplementary.csv", sep=";", header = T)
boden_historic_long<- read.csv2("Data_MineralSoil_Supplementary.csv", sep=";", header = T)
bod_15 <- read.xlsx2("Data_MineralSoil_2015_Supplementary.xlsx", sheetName = 1,
                     colClasses = c(rep("character", 5), rep("numeric", ncol(bod_15)-5+1)) )

site <- as.character(sort(unique(boden_historic_long$Name)))

#############################################################################################################################
#############################################################################################################################

setwd("/Users/leldite/-EDUCATION/PhD/Analysis 1/Results")

####### 1 #######
# CA & PCA for site groups
#######   #######
# in sampling year 2015 (because of highest number of repetitions, and FBV)

# 1- select site Null treatment, and combine soil layers into 0-30 cm (0-60 cm has 1 missing FBV)

bod_15_0_30 <- bod_15 %>%
  filter(Treatment == "Control") %>%
  filter(!(Depth == "30-60cm")) %>%
  
  
  select(-Sample_Date) %>% # keep only information of UniqueID and relevant parameters
  
  
  group_by(Name, UniqueID) %>%
  summarise(CEC = sum(FBV * CEC) / sum(FBV),
            Al = sum(FBV * Al) / sum(FBV),
            Al_tot_Stock = sum(Al_tot_Stock),
            Al... = sum(FBV * Al...) / sum(FBV),
            Al_CEC_Stock = sum(Al_CEC_Stock),
            BS = sum(FBV * BS) / sum(FBV),
            Ca = sum(FBV * Ca) / sum(FBV),
            Ca_tot_Stock = sum(Ca_tot_Stock),
            Ca.. = sum(FBV * Ca..) / sum(FBV),
            Ca_CEC_Stock = sum(Ca_CEC_Stock),
            Carbon = sum(FBV * Carbon) / sum(FBV),
            C_Stock = sum(C_Stock),
            Fe = sum(FBV * Fe) / sum(FBV),
            Fe_tot_Stock = sum(Fe_tot_Stock),
            Fe... = sum(FBV * Fe...) / sum(FBV),
            Fe_CEC_Stock = sum(Fe_CEC_Stock),
            K = sum(FBV * K) / sum(FBV),
            K_tot_Stock = sum(K_tot_Stock),
            K. = sum(FBV * K.) / sum(FBV),
            K_CEC_Stock = sum(K_CEC_Stock),
            Mg = sum(FBV * Mg) / sum(FBV),
            Mg_tot_Stock = sum(Mg_tot_Stock),
            Mg.. = sum(FBV * Mg..) / sum(FBV),
            Mg_CEC_Stock = sum(Mg_CEC_Stock),
            Nitrogen = sum(FBV * Nitrogen) / sum(FBV),
            N_Stock = sum(N_Stock),
            pH_H2O = log10(sum(FBV * pH_mol_Liter_H2O) / sum(FBV)) * -1,
            pH_mol_Liter_H2O = sum(FBV * pH_mol_Liter_H2O) / sum(FBV),
            pH_KCl = log10(sum(FBV *pH_mol_Liter_KCl) / sum(FBV)) * -1,
            pH_mol_Liter_KCl = sum(FBV * pH_mol_Liter_KCl) / sum(FBV),
            TRD = mean(TRD),
            TRD_FB = mean(TRD_FB),
            FBV = as.numeric(sum(FBV))
  )
  
bod_15_0_30 <- as.data.frame(bod_15_0_30)


#### Cluster Analysis ####
bod_15_0_30_transform <- bod_15_0_30 %>%
  mutate(Ca_CEC_V_log = log(Ca_CEC_Stock)) %>%
  mutate(K_CEC_V_log = log(K_CEC_Stock)) %>%
  #  mutate(Mg_CEC_V_power0.5 = (Mg_CEC_Stock)^0.5) %>%
  mutate(Mg_CEC_V_log= log(Mg_CEC_Stock))

bod_15_0_30_cluster <- bod_15_0_30_transform %>%
  select(UniqueID, CEC, Al_CEC_Stock, Ca_CEC_V_log, Fe_CEC_Stock, K_CEC_V_log, Mg_CEC_V_log, C_Stock, N_Stock, pH_H2O, pH_KCl)

# 1- make sure NAs are removed, and data is rescaled for better comparability
bod_15_0_30_cluster <- na.omit(bod_15_0_30_cluster) # listwise deletion of missing
bod_15_0_30_cluster_scaled <- scale(bod_15_0_30_cluster[,-1]) # standardize variables

# 2- Determine number of clusters
wss <- (nrow(bod_15_0_30_cluster_scaled)-1)*sum(apply(bod_15_0_30_cluster_scaled,2,var))
for (i in 2:15) wss[i] <- sum(kmeans(bod_15_0_30_cluster_scaled, 
                                     centers=i)$withinss)
plot(1:15, wss, type="b", xlab="Number of Clusters",
     ylab="Within groups sum of squares")

# 3- K-Means Cluster Analysis
#### with standard R ####
fit <- kmeans(bod_15_0_30_cluster_scaled, 2) # with n of groups as cluster solution
# get cluster means 
aggregate(bod_15_0_30_cluster_scaled,by=list(fit$cluster),FUN=mean)
# append cluster assignment
clusters_result_v2 <- data.frame(bod_15_0_30_cluster_scaled, fit$cluster)

site_groups_CA_v2 <- cbind(as.data.frame(bod_15_0_30[,1:2]), clusters_result_v2 [,11])

# Cluster Plot against 1st 2 principal components
# vary parameters for most readable graph
library(cluster) 
clusplot(bod_15_0_30_cluster_scaled, fit$cluster, color=TRUE, shade=TRUE, 
         labels=2, lines=0)

#######################
##### 3b - hierarchical clustering with Ward's method ####
row.names(bod_15_0_30_cluster_scaled) <- bod_15_0_30[,1] # make site as row names

# Ward Hierarchical Clustering
d <- dist(bod_15_0_30_cluster_scaled, method = "euclidean") # distance matrix
fit <- hclust(d, method="ward") 
plot(fit) # display dendogram
groups <- cutree(fit, k=2) # cut tree into n clusters
# draw dendogram with red borders around the n clusters 
rect.hclust(fit, k=2, border="red")
######################

#### PCA ####

# 2- check dimensinality of data
par(mfrow = c(1,1), mar=c(8,4,2,1))
boxplot(bod_15_0_30[,-c(1,2)], las=2) #  , ylim = c(0,50)
#  obvioulsy a highly complex data set with different ranges, magnitudes and variances!

# 3- check for Gaussian distribution (=normality)
par(mfrow = c(3,4), mar= c(2,2,1,1))
for (parameter in names(bod_15_0_30[,-c(1,2)])) {
  test <- shapiro.test(bod_15_0_30[, parameter])
  hist(bod_15_0_30[, parameter], breaks= 12, main = paste0(parameter,", ", round(test$p.value,2)), xlab="")
  qqnorm(bod_15_0_30[,parameter], main = paste0(parameter,", ", round(test$p.value,2))); qqline(bod_15_0_30[,parameter], col = 2)
}

#### v1 ####
# try log-transforming not normally distributed cation stocks
bod_15_0_30_transform <- bod_15_0_30 %>%
  mutate(Ca_CEC_V_log = log(Ca_CEC_Stock)) %>%
  mutate(K_CEC_V_log = log(K_CEC_Stock)) %>%
#  mutate(Mg_CEC_V_power0.5 = (Mg_CEC_Stock)^0.5) %>%
  mutate(Mg_CEC_V_log= log(Mg_CEC_Stock))

par(mfrow = c(2,4), mar= c(2,2,1,1))
for (parameter in names(bod_15_0_30_transform[,c(36:38)])) {
  test <- shapiro.test(bod_15_0_30_transform[, parameter])
  hist(bod_15_0_30_transform[, parameter], breaks= 12, main = paste0(parameter,", ", round(test$p.value,2)), xlab="")
  qqnorm(bod_15_0_30_transform[,parameter], main = paste0(parameter,", ", round(test$p.value,2))); qqline(bod_15_0_30_transform[,parameter], col = 2)
}
# Mg still not normally distributed: right skew - use anyway?!

bod_15_0_30_norm <- bod_15_0_30_transform %>%
  select(CEC, Al_CEC_Stock, Ca_CEC_V_log, Fe_CEC_Stock, K_CEC_V_log, Mg_CEC_V_log, C_Stock, N_Stock, pH_H2O, pH_KCl) %>%
  rename(CEC = CEC,
         Al = Al_CEC_Stock,
         Ca = Ca_CEC_V_log,
         Fe = Fe_CEC_Stock,
         K = K_CEC_V_log, 
         Mg = Mg_CEC_V_log, 
         C = C_Stock, 
         N = N_Stock, 
         "pH-H2O" = pH_H2O, 
         "pH-KCl" = pH_KCl)


# 4- check correlations
pdf(file = paste0("Pairwise_correlations","_0-30cm", "_v1", ".pdf",sep=""),
    family="Helvetica-Narrow")
pairs(bod_15_0_30_norm)
dev.off()
# some correlations visible, so PCA should be able to reduce data dimensionality


# 5- Covariance or correlation matrix PCA?
round(diag(cov(bod_15_0_30_norm)),2)
# differences on covariances mostly too large
round(cor(bod_15_0_30_norm),2)
# some incidences of high correlation (>0.7) visible
# correlation matrix therefore most appropriate!


# 6- PCA
bod_15_0_30_pca <- prcomp(bod_15_0_30_norm, center = T, scale. = T)

# 1) check eigenvectors
v_eigenvalues <- round(bod_15_0_30_pca$sdev^2, 2)
round(bod_15_0_30_pca$rotation, 2)

# 2) check how many relevant principal components
pca_variance <- as.data.frame(v_eigenvalues) 
pca_variance$percentage <- round(pca_variance$v_eigenvalues / sum(pca_variance$v_eigenvalues)*100, 1)
# [1] 33.8 31.1 13.8  8.9  5.3  3.6  1.5  1.0  0.7  0.4
pca_variance$cumulative_percentage <- cumsum(pca_variance$percentage)
# [1] 33.8  64.9  78.7  87.6  92.9  96.5  98.0  99.0  99.7 100.1

# according to Kaiser (1960) the relevant principal components vill have values >1
pca_kaiser <- mean(v_eigenvalues)
pca_kaiser_index <- round(v_eigenvalues/pca_kaiser, 2)
#  [1] 3.38 3.11 1.38 0.89 0.53 0.36 0.15 0.10 0.07 0.04
# here: first 2 (-3) principal components >1, and in total explain 64.9 (-78.7) % variabilty in the data

bod_15_0_30_z <- scale(bod_15_0_30_norm, center = T, scale = T)
m_cormatrix <- round(cor(bod_15_0_30_z), 2)
require(psych)
par(mfrow = c(1,1), mar=c(8,4,2,1))
VSS.scree(m_cormatrix)

# 3) visualise the 4 relevant PCs
pdf(file = paste0("PCA","_0-30cm","_v1", ".pdf",sep=""),
    family="Helvetica-Narrow")
# by site
par(mfrow=c(1,1), mar = c(5,5,1,1))
axis <- range(bod_15_0_30_pca$x[,1]*1.1, bod_15_0_30_pca$x[,2]*1.1)
plot(bod_15_0_30_pca$x[,1], bod_15_0_30_pca$x[,2], type= "n", cex = 0.5,
     ylim = axis, xlim = axis,  # same scaling for both PCs!
     xlab = paste0("PC 1 (", pca_variance$percentage[1], "%)"),
     ylab = paste0("PC 2 (", pca_variance$percentage[2], "%)")
)
abline(h=0, v=0, col="gray")

pca_col_fun <- colorRampPalette(
  colors = c("darkred", "red", "orange", "yellow", "green", "darkgreen", "lightblue", "blue", "darkblue", "violet"),
  space = "Lab" # Option used when colors do not represent a quantitative scale
)
pca_col <- pca_col_fun(nlevels(bod_15_0_30$Name))

text(bod_15_0_30_pca$x[,1], bod_15_0_30_pca$x[,2], 
     labels = abbreviate(bod_15_0_30$Name, minlength = 3), 
     cex=0.8, col= pca_col[bod_15_0_30$Name])

# by parameter
par(mfrow=c(1,1), mar = c(5,5,1,1))
axis <- range(bod_15_0_30_pca$rotation[,1]*1.1, bod_15_0_30_pca$rotation[,2]*1.1)
plot(bod_15_0_30_pca$rotation[,1], bod_15_0_30_pca$rotation[,2], type= "n", cex = 0.5,
     ylim = axis, xlim = axis,  # same scaling for both PCs!
     xlab = paste0("PC 1 (", pca_variance$percentage[1], "%)"),
     ylab = paste0("PC 2 (", pca_variance$percentage[2], "%)")
)
arrows(0, 0, bod_15_0_30_pca$rotation[,1], bod_15_0_30_pca$rotation[,2], 
       col = "darkgray", length = 0.15, angle = 20)
abline(h=0, v=0, col="gray")
text(bod_15_0_30_pca$rotation[,1], bod_15_0_30_pca$rotation[,2], 
     labels = substr(colnames(bod_15_0_30_norm), 1,7), cex=0.8)

dev.off()


#### RESULT SITE GROUPING: PCA / CA ####
# compare 1) site N_Stock / C_Stock, Ake, Al_CEC_Stock,
#         2) pH..H2O. & pH..KCl., Ca / Mg_CEC_Stock, Fe_CEC_Stock

site1 <- c("Bad Waldsee", "Ellwangen", "Freudenstadt", "Heidelberg", "Ochsenhausen")
site2 <- c( "Horb", "Herzogenweiler", "Hospital", "Wangen", "Weithard")

site_groups <- list(site1, site2, site)


#### detailed PCA parameter distributions by Group ####
bod_15_0_30 <- mutate(bod_15_0_30, Group = ifelse(Name %in% site1, "G1", "G2")) %>%
  arrange(factor(Name, levels = c("Bad Waldsee", "Ellwangen", "Freudenstadt", "Heidelberg", "Ochsenhausen", 
                                   "Horb", "Herzogenweiler", 
                                   "Hospital", "Wangen", "Weithard")))

PC_parameters <- c("pH_H2O","pH_KCl","K_CEC_Stock",  "C_Stock","N_Stock","CEC", "Al_CEC_Stock")

pdf(file = paste0("Boxplots_afterPCA","_0-30cm", ".pdf"),
    family="Helvetica-Narrow")

for (i in PC_parameters) {
  boxplot(bod_15_0_30[[i]] ~ bod_15_0_30$Group, 
          las=1, main = i) # , names = unique(abbreviate(bod_15_0_30$Name, minlength = 3))
  abline(h = median(bod_15_0_30[[i]]), col="red",lwd = 2, lty=2)
  
  boxplot(bod_15_0_30[[i]] ~ bod_15_0_30$Name, 
          las=2, main = i, names = unique(abbreviate(bod_15_0_30$Name, minlength = 3)))
  abline(h = median(bod_15_0_30[[i]]), col="red",lwd = 2, lty=2)
}

dev.off()


####### 2 #######
# time since treatment significant y/n
# all sites, seperate by treatment [control, limed]
# predictor levels: 2003, 2010, 2015 (all 10 sites)
# method: Friedman-test, for repeated (dependent) measurements
# a ~ b | c, where a=values [parameter], b=groups [year] and c=blocks [site] 
# (unreplicated -> must calculate means first before applying test)
#######   #######

# calculate means
calc_means <- function(data) {
  output <- data %>%
    filter(Name %in% site_groups[[i]]) %>%
    droplevels()  %>%
    group_by(Name, Treatment, Depth, Year, Parameter) %>%
    summarise(Measurement = mean(Measurement, na.rm = TRUE)) %>%
    ungroup()
  return(output)
}

# test
selectFriedmanPValue <- function(friedman_output) {
  return(friedman_output$p.value)
}

selectFriedmanPosthocPValue <- function(posthoc_output, row, col) {
  data <- posthoc_output[["p.value"]]
  return(data[row, col])
}

test_friedman <- function(data) {
  output <- data %>%
    group_by(Depth, Treatment, Parameter) %>%
    summarise(
      friedman.p = selectFriedmanPValue(friedman.test(y = Measurement, groups = Year, blocks = Name)),
      posthoc_03.10 = selectFriedmanPosthocPValue(
        posthoc.friedman.conover.test(y = Measurement, groups = Year, blocks = Name, p.adjust.method = "fdr"),
        row = 1, col = 1),
      posthoc_03.15 = selectFriedmanPosthocPValue(
        posthoc.friedman.conover.test(y = Measurement, groups = Year, blocks = Name, p.adjust.method = "fdr"),
        row = 2, col = 1),
      posthoc_10.15 = selectFriedmanPosthocPValue(
        posthoc.friedman.conover.test(y = Measurement, groups = Year, blocks = Name, p.adjust.method = "fdr"),
        row = 2, col = 2)
    ) %>%
    mutate_if(is.numeric, round, 3)
  return(output)
}


friedman_by_year <- list()

for (i in c(1:3)) {
  # i <- 1
  
  hum_historic_mean <- calc_means(humus_historic_long)
  hum_historic_friedman <- test_friedman(hum_historic_mean)

  bod_historic_mean <- calc_means(boden_historic_long)
  bod_historic_friedman <- test_friedman(bod_historic_mean)

  friedman_by_year[[i]] <- bind_rows(hum_historic_friedman, bod_historic_friedman)
  
  write.csv2(friedman_by_year[[i]],
             paste0("Friedman_by_year_Group-",i,".csv"),
             col.names= T, row.names = F)
}

####### 3 #######
# treatment significant y/n
# all sites, by sampling year
# 1st choice: Mann-Whitney U test if Variants on Site considered "independent"
#######   #######

selectMWUpValue <- function(wilcoxon_output) {
  return(wilcoxon_output$p.value)
}

test_mann_whiteney_u <- function(data) {
  output <- data %>%
    filter(Name %in% site_groups[[i]]) %>%
    droplevels()  %>%
    group_by(Depth, Year, Parameter) %>%
    summarise(
      mwu.p = selectMWUpValue(wilcox.test(Measurement ~ Treatment, alternative="two.sided", 
                                          paired = F, p.adjust.methods = "fdr"))) %>%
    mutate_if(is.numeric, round, 3)
  return(output)
}


MWU_by_treatment <- list()

for (i in c(1:3)) {
  # i <- 1
  
  hum_historic_MWU <- test_mann_whiteney_u(humus_historic_long)
  
  bod_historic_MWU<- test_mann_whiteney_u(boden_historic_long)
  
  MWU_by_treatment[[i]] <- bind_rows(hum_historic_MWU, bod_historic_MWU)
  
  write.csv2(MWU_by_treatment[[i]],
             paste0("Mann-Whitney-U_by_treatment_Group-",i,".csv"),
             col.names= T, row.names = F)
}


####### 4 #######
# create overview Table:
# historic development 2003 - 2015
# by Parameter SoilChem
#######   #######

# to calculate means: first arithmetic mean per site, then mean for the entire group - to make all sites equally weighted even when the occasional repetion sample missing
# to calculate SD: use the entire group, accross all sites
overview_means <- function(data) {
  # data <- humus_historic_long
  # i <- 2
  output_1 <- data %>%
    filter(Name %in% site_groups[[i]]) %>%
    droplevels()
  
  # simple arithmetic means and regular SDs for all Parameters except pH mol/L
  output_2a <- output_1 %>%
    filter(!(grepl("pH", Parameter))) %>%
    group_by(Parameter, Unit, Name, Depth, Treatment, Year) %>%
    summarise(Mean_site = (mean(Measurement, na.rm=TRUE))) %>%
    ungroup() %>%
    group_by(Parameter, Unit, Depth, Treatment, Year) %>%
    summarise(Mean_group = (mean(Mean_site, na.rm=TRUE))) %>%
    ungroup()
  
  output_2b <- output_1 %>%
    filter(!(grepl("pH", Parameter))) %>%
    group_by(Parameter, Unit, Depth, Treatment, Year) %>%
    summarise(SDs = sd(Measurement, na.rm=TRUE)) %>%
    ungroup()
  
  output_2_final <- merge(output_2a, output_2b, by = c("Parameter", "Unit", "Depth","Treatment","Year")) %>%
    mutate_if(is.numeric, round, 2) %>%
    mutate(Mean_SD = paste0(Mean_group," (", SDs, ")") ) %>%
    select(Parameter, Unit, Depth, Treatment, Year, Mean_SD) %>%
    spread(Year, Mean_SD) %>%
    ungroup()
  
  # arithmetic means of pH mol/L, only the final result reconverted to pH
  # SD from measured pH values 
  output_3a <- output_1 %>%
    filter(grepl("pH_mol_Liter", Parameter)) %>%
    group_by(Parameter, Unit, Name, Depth, Treatment, Year) %>%
    summarise(Mean_site = (mean(Measurement, na.rm=TRUE))) %>%
    ungroup() %>%
    group_by(Parameter, Unit, Depth, Treatment, Year) %>%
    summarise( Mean_group_molL = (mean(Mean_site, na.rm=TRUE)),
               Mean_group = log10(mean(Mean_site, na.rm=TRUE))*-1 ) %>%
    ungroup() %>%
    mutate(Parameter = ifelse(Parameter == "pH_mol_Liter_H2O", "pH_H2O", 
                              ifelse(Parameter == "pH_mol_Liter_KCl", "pH_KCl", Parameter)) )
  
  output_3b <- output_1 %>%
    filter(grepl("pH", Parameter)) %>%
    filter(!(grepl("pH_mol_Liter", Parameter)) ) %>%
    group_by(Parameter, Unit, Depth, Treatment, Year) %>%
    summarise( SDs = sd(Measurement, na.rm=TRUE)) %>%
    ungroup()
  
  output_3_final <- merge(output_3a, output_3b, by = c("Parameter", "Unit", "Depth","Treatment","Year")) %>%
    mutate_if(is.numeric, round, 2) %>%
    mutate(Mean_SD = paste0(Mean_group," (", SDs, ")") ) %>%
    select(Parameter, Unit, Depth, Treatment, Year, Mean_SD) %>%
    spread(Year, Mean_SD) %>%
    ungroup()
  
  output <- rbind(output_2_final, output_3_final)
  
  return(output)
}


for (i in c(1:3)) {
  # i <- 1
  
hum_historic_summary <- overview_means(humus_historic_long)
bod_historic_summary <- overview_means(boden_historic_long) 

historic_summary <- bind_rows(hum_historic_summary, bod_historic_summary) %>%
  arrange(Parameter)
historic_summary <- historic_summary[c("Parameter","Unit", "Depth","Treatment", "2003", "2010", "2015")]

write.csv2(historic_summary,
           paste0("Historic_development_Group-",i, ".csv"),
           col.names= T, row.names = F)
}


####### 5 #######
# Effect size:
# calculate ((Year2/Year1) – 1) as Response Ratio between sampling years
# for discontinuous, transformed, or already relative variables use mean difference (limed – control) and (Y2 - Y1) instead!
#######   #######

# calculate means per site per treatment (per year)
calc_means <- function(data) {
  output <- data %>%
    filter(Name %in% site_groups[[i]])
  
  output_1 <- output %>%
    filter(!(grepl("pH", Parameter))) %>%
    droplevels()  %>%
    group_by(Parameter, Name, Treatment, Depth, Year) %>%
    summarise( sample_mean = mean(Measurement, na.rm = TRUE) ) %>%
    ungroup()
  
  output_2 <- output %>%
    filter(grepl("pH_mol_Liter", Parameter)) %>%
    droplevels()  %>%
    group_by(Parameter, Name, Treatment, Depth, Year) %>%
    summarise( sample_mean = log10(mean(Measurement, na.rm = TRUE))*-1 ) %>%
    ungroup() %>%
    mutate(Parameter = ifelse(Parameter == "pH_mol_Liter_H2O", "pH_H2O", 
                              ifelse(Parameter == "pH_mol_Liter_KCl", "pH_KCl", Parameter)) )
    
  output_final <- rbind(output_1, output_2)
  return(output_final)
}

relative_parameters <- c("BS", "C.N", "pH_H2O", "pH_KCl") # pH means were calculated from [H+] mol/Liter
# calculate ((Year2/Year1) – 1) as relarive difference
# for discontinuous, transformed, or already relative variables use mean difference (Year2 - Year1) instead!
calc_effect_size_year <- function(data) {
  output_regular_1 <- data %>%
    filter(!(Parameter %in% relative_parameters)) %>%
    group_by(Parameter, Unit, Name, Depth, Treatment) %>%
    summarise(Period = "d2003.2010",
              Effect_size = ((sample_mean[Year == "2010"] / sample_mean[Year == "2003"]) -1 ) ,
              Site_mean_start = sample_mean[Year == "2003"],
              Site_mean_end = sample_mean[Year == "2010"]
              )
  output_regular_3 <- data %>%
    filter(!(Parameter %in% relative_parameters)) %>%
    group_by(Parameter, Unit, Name, Depth, Treatment) %>%
    summarise(Period = "d2010.2015",
              Effect_size = ((sample_mean[Year == "2015"] / sample_mean[Year == "2010"]) -1 ) ,
              Site_mean_start = sample_mean[Year == "2010"],
              Site_mean_end = sample_mean[Year == "2015"]
    )

  output_relative_1 <- data %>%
    filter(Parameter %in% relative_parameters) %>%
    group_by(Parameter, Unit, Name, Depth, Treatment) %>%
    summarise(Period = "d2003.2010",
              Effect_size = (sample_mean[Year == "2010"] - sample_mean[Year == "2003"]) , # from ratio, % or pH to relative difference
              Site_mean_start = sample_mean[Year == "2003"],
              Site_mean_end = sample_mean[Year == "2010"]
    )
  output_relative_3 <- data %>%
    filter(Parameter %in% relative_parameters) %>%
    group_by(Parameter, Unit, Name, Depth, Treatment) %>%
    summarise(Period = "d2010.2015",
              Effect_size = (sample_mean[Year == "2015"] - sample_mean[Year == "2010"]) , # from ratio, % or pH to relative difference
              Site_mean_start = sample_mean[Year == "2010"],
              Site_mean_end = sample_mean[Year == "2015"]
    )

  output <- bind_rows(output_regular_1,output_regular_3, output_relative_1,output_relative_3)
  # output_regular_2, output_relative_2,
  
  return(output)
} 


# compose the Effects Size table for time effect
calc_effects_table_year <- function(data) {
  output <- data %>%
    group_by(Parameter, Unit, Depth, Period, Treatment)  %>%
    summarise(ES_mean = round(mean(Effect_size, na.rm=TRUE),2),
              ES_sd = round(sd(Effect_size, na.rm=TRUE),2),
              ES_N_minus = sum(Effect_size < 0, na.rm=TRUE),
              ES_N_plus = sum(Effect_size > 0, na.rm=TRUE),
              ES_range = paste0(round(range(Effect_size, na.rm=TRUE)[1], 2), " - ", round(range(Effect_size, na.rm=TRUE)[2], 2) )
              ) %>%
    arrange(Period) %>%
    arrange(factor(Depth, levels = c("O-layer","0-5cm","5-10cm","10-30cm","30-60cm"))) %>%
    arrange(Parameter)
  return(output)
}


for (i in c(1:3)) {
  # i <- 2
  
  # 1: calculate means per site per treatment (per year)
  humus_tab1 <- calc_means(humus_historic_long)
  boden_tab1 <- calc_means(boden_historic_long)
  profile_tab2 <- bind_rows(humus_tab1, boden_tab1)
  
  parameters_year_friedman <- friedman_by_year[[i]] %>%
    select(-c("friedman.p", "posthoc_03.15")) %>%
    gather(key = "Period", value = "FRDM.p", -c("Depth", "Treatment", "Parameter"), na.rm = T) %>%
    mutate(Period = gsub("posthoc_", "d", Period)) %>%
    mutate(Period = gsub("03", "2003", Period)) %>%
    mutate(Period = gsub("10", "2010", Period)) %>%
    mutate(Period = gsub("15", "2015", Period))

  # 3: calculate effect size per site 
  # calculate ((Year2/Year1) – 1) as relarive difference
  # for discontinuous, transformed, or already relative variables use mean difference (Y2 – Y1) instead!
  # all parameters at all profile depths (including the non-significant ones)
  effect_size_data_year <- calc_effect_size_year(profile_tab2)
  
  # plot:
  effect_size_data_year_pval <- left_join(effect_size_data_year, parameters_year_friedman, by=c("Depth","Treatment","Period","Parameter")) %>%
    ungroup() %>%
    mutate(Parameter = gsub("Al...", "Al", Parameter)) %>%
    mutate(Parameter = gsub("Fe...", "Fe", Parameter)) %>%
    mutate(Parameter = gsub("Ca..", "Ca", Parameter, fixed = T)) %>%
    mutate(Parameter = gsub("Mg..", "Mg", Parameter, fixed = T)) %>%
    mutate(Parameter = gsub("K.", "K", Parameter, fixed = T))
  
  # unique(effect_size_data_year_pval$Parameter)
  
  param_boxplot <- c("Carbon", "Nitrogen", "BS", "pH_H2O", "pH_KCl", "Ca", "Mg", "Al", "Fe", "K","OL_stock")
  label_boxplot <- c("RR C","RR N", "RR Base saturation", expression('RR pH (H' [2] * 'O)'), "RR pH (KCl)", "RR Ca", "RR Mg", "RR Al", "RR Fe", "RR K", "RR O-layer stock") 
  
  select_boxplot_data <- function(data) {
    output <- data %>%
      ungroup() %>%
      filter(Parameter %in% param_boxplot[p])  %>%
      droplevels()
    return(output)
  }
  
  
    for (p in c(1:10)) {  # start parameters, without OL_stock
      # p <- 2
      
      pdf(file = paste0("Boxplots_Effect_sizes_Group-", i, "_", param_boxplot[p], ".pdf"),
          family="Helvetica-Narrow", 
          width = 6,
          height = 12,
          pointsize = 10
      )
      
      par(mar = c(5,6,2,6), mfrow = c(2,1))
      
      box_colors <- c(rgb(179,217,255, maxColorValue = 255), rgb(166,77,255, maxColorValue = 255))
      
      profile_boxplot_data <- select_boxplot_data(effect_size_data_year_pval) %>%
        arrange(factor(Depth, levels = c("O-layer","0-5cm","5-10cm","10-30cm","30-60cm")))
      
      range_x <- c(min(profile_boxplot_data$Effect_size, na.rm = T), max(profile_boxplot_data$Effect_size, na.rm = T)*1.05 )    # Parameter values range
      range_y <- range(0.5, 6)  # Profile depth
      
      
      boxplot_data_03_10 <- profile_boxplot_data %>%
        filter(Period == "d2003.2010") %>%
        droplevels()
      
      plot(x=0, xlim=range_x, ylim=range_y, axes = T, las = 1, col = "white",  yaxt="n", # to remove numbers of y axis
           ylab = "", xlab = label_boxplot[p], las = 1, cex.axis=1.5, cex.lab=2)
      axis(side = 2, at = c(5,4,3,2,1), labels = c("O-layer","0-5cm","5-10cm","10-30cm","30-60cm"), las = 1, cex.axis=1.5, cex.lab=2)
      abline(v=0)
      
      if (p != 3) {   # when Base saturation, no data for O-layer 
        boxplot(data = boxplot_data_03_10 [boxplot_data_03_10$Depth == "O-layer",] ,
                Effect_size ~ Treatment,  
                add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors, axes = FALSE,
                at = c(5.1, 4.9))
      }
      
      boxplot(data = boxplot_data_03_10 [boxplot_data_03_10$Depth == "0-5cm",] ,
              Effect_size ~ Treatment,   
              add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors, axes = FALSE,
              at = c(4.1, 3.9))
      boxplot(data = boxplot_data_03_10 [boxplot_data_03_10$Depth == "5-10cm",] ,
              Effect_size ~ Treatment,  
              add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors, axes = FALSE,
              at = c(3.1, 2.9))
      boxplot(data = boxplot_data_03_10 [boxplot_data_03_10$Depth == "10-30cm",] ,
              Effect_size ~ Treatment,  
              add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors, axes = FALSE,
              at = c(2.1, 1.9))
      boxplot(data = boxplot_data_03_10 [boxplot_data_03_10$Depth == "30-60cm",] ,
              Effect_size ~ Treatment,
              add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors, axes = FALSE,
              at = c(1.1, 0.9))
      
      # # label: treatment
      # if (p != 3) {
      #   text(x = max(profile_boxplot_data$Effect_size, na.rm = T)*1.05 , 
      #        y = c(5.1,4.9, 4.1,3.9, 3.1,2.9, 2.1,1.9, 1.1, 0.9),
      #        label = c("Control", "Limed"),
      #        adj=0, cex=1)
      # } else {   # when Base saturation, no data for O-layer
      #   text(x = max(profile_boxplot_data$Effect_size, na.rm = T)*1.05 , 
      #        y = c(4.1,3.9, 3.1,2.9, 2.1,1.9, 1.1, 0.9),
      #        label = c("Control", "Limed"),
      #        adj=0, cex=1)
      # }
      
      legend("top", 
             legend = c("Control", "Limed"),
             fill = box_colors,
             bty = "o", 
             ncol = 2,
             cex = 1.4)
      
      # label: significant y/n according to Freidman
      label_signif_03_10 <-  unique(select(boxplot_data_03_10, .data$Depth, .data$Treatment, .data$FRDM.p)) %>%
        mutate(signif_lvl = ifelse(FRDM.p < 0.05, "*", ""))
      if (p != 3) {
        text(x = max(profile_boxplot_data$Effect_size, na.rm = T)*1.02 , 
             y = c(5.1,4.9, 4.1,3.9, 3.1,2.9, 2.1,1.9, 1.1, 0.9),
             label = label_signif_03_10$signif_lvl,
             adj=0, cex=2)
      } else {   # when Base saturation, no data for O-layer
        text(x = max(profile_boxplot_data$Effect_size, na.rm = T)*1.02 , 
             y = c(4.1,3.9, 3.1,2.9, 2.1,1.9, 1.1, 0.9),
             label = label_signif_03_10$signif_lvl,
             adj=0, cex=2)
      }
      
      mtext("2003 - 2010", side = 4, cex = 2.2, line = 3)
      
      
      boxplot_data_10_15 <- profile_boxplot_data %>%
        filter(Period == "d2010.2015") %>%
        droplevels()
      
      plot(x=0, xlim=range_x, ylim=range_y, axes = T, las = 1, col = "white",  yaxt="n", # to remove numbers of y axis
           ylab = "", xlab = label_boxplot[p], las = 1, cex.axis=1.5, cex.lab=2)
      axis(side = 2, at = c(5,4,3,2,1), labels = c("O-layer","0-5cm","5-10cm","10-30cm","30-60cm"), las = 1, cex.axis=1.5, cex.lab=2)
      abline(v=0)
      
      if (p != 3) {   # when Base saturation, no data for Humus layer
        boxplot(data = boxplot_data_10_15 [boxplot_data_10_15$Depth == "O-layer",] ,
                Effect_size ~ Treatment,  
                add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors, axes = FALSE,
                at = c(5.1, 4.9))
      }
      
      boxplot(data = boxplot_data_10_15 [boxplot_data_10_15$Depth == "0-5cm",] ,
              Effect_size ~ Treatment,   
              add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors, axes = FALSE,
              at = c(4.1, 3.9))
      boxplot(data = boxplot_data_10_15 [boxplot_data_10_15$Depth == "5-10cm",] ,
              Effect_size ~ Treatment,  
              add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors, axes = FALSE,
              at = c(3.1, 2.9))
      boxplot(data = boxplot_data_10_15 [boxplot_data_10_15$Depth == "10-30cm",] ,
              Effect_size ~ Treatment,  
              add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors, axes = FALSE,
              at = c(2.1, 1.9))
      boxplot(data = boxplot_data_10_15 [boxplot_data_10_15$Depth == "30-60cm",] ,
              Effect_size ~ Treatment,
              add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors, axes = FALSE,
              at = c(1.1, 0.9))
      
      # if (p != 3) {
      #   text(x = max(profile_boxplot_data$Effect_size, na.rm = T)*1.05 , 
      #        y = c(5.1,4.9, 4.1,3.9, 3.1,2.9, 2.1,1.9, 1.1, 0.9),
      #        label = c("Control", "Limed"),
      #        adj=0, cex=1)
      # } else {   # when Base saturation, no data for Humus layer
      #   text(x = max(profile_boxplot_data$Effect_size, na.rm = T)*1.05 , 
      #        y = c(4.1,3.9, 3.1,2.9, 2.1,1.9, 1.1, 0.9),
      #        label = c("Control", "Limed"),
      #        adj=0, cex=1)
      # }
      
      legend("top", 
             legend = c("Control", "Limed"),
             fill = box_colors,
             bty = "o", 
             ncol = 2,
             cex = 1.4)
      
      # label: significant y/n according to Freidman
      label_signif_10_15 <-  unique(select(boxplot_data_10_15, .data$Depth, .data$Treatment, .data$FRDM.p)) %>%
        mutate(signif_lvl = ifelse(FRDM.p < 0.05, "*", ""))
      if (p != 3) {
        text(x = max(profile_boxplot_data$Effect_size, na.rm = T)*1.02 , 
             y = c(5.1,4.9, 4.1,3.9, 3.1,2.9, 2.1,1.9, 1.1, 0.9),
             label = label_signif_10_15$signif_lvl,
             adj=0, cex=2)
      } else {   # when Base saturation, no data for Humus layer
        text(x = max(profile_boxplot_data$Effect_size, na.rm = T)*1.02 , 
             y = c(4.1,3.9, 3.1,2.9, 2.1,1.9, 1.1, 0.9),
             label = label_signif_10_15$signif_lvl,
             adj=0, cex=2)
      }
      
      mtext("2010 - 2015", side = 4, cex = 2.2, line = 3)
      
      dev.off()
      
    } # end parameter 1:10, without OL_stock
  
  
  p <- 11 #begin OL_stock plot
  
  pdf(file = paste0("Boxplots_Effect_sizes_Group-", i, "_", param_boxplot[p], ".pdf"),
      family="Helvetica-Narrow", 
      width = 6,
      height = 5,
      pointsize = 10
  )
  
  par(mar = c(5,6,2,6), mfrow = c(2,1))
  
  box_colors <- c(rgb(179,217,255, maxColorValue = 255), rgb(166,77,255, maxColorValue = 255))
  
  profile_boxplot_data <- select_boxplot_data(effect_size_data_year_pval)
  
  range_x <- c(min(profile_boxplot_data$Effect_size, na.rm = T), max(profile_boxplot_data$Effect_size, na.rm = T)*1.05 )    # Parameter values range
  range_y <- range(0, 1)  # Profile depth
  
  
  boxplot_data_03_10 <- profile_boxplot_data %>%
    filter(Period == "d2003.2010") %>%
    droplevels()
  
  plot(x=0, xlim=range_x, ylim=range_y, axes = T, las = 1, col = "white",  yaxt="n", # to remove numbers of y axis
       ylab = "", xlab = label_boxplot[p], las = 1, cex.axis=1.5, cex.lab=2)
  axis(side = 2, at = 0.5, labels = "O-layer", las = 1, cex.axis=1.5, cex.lab=2)
  abline(v=0)
  
  boxplot(data = boxplot_data_03_10,
          Effect_size ~ Treatment,   
          add = TRUE, horizontal = T, boxwex = 0.10, col = box_colors, axes = FALSE,
          at = c(0.4, 0.28))
  
  
  legend("top", 
         legend = c("Control", "Limed"),
         fill = box_colors,
         bty = "o", 
         ncol = 2,
         cex = 1.4)
  
  # label: significant y/n according to Freidman
  label_signif_03_10 <-  unique(select(boxplot_data_03_10, .data$Depth, .data$Treatment, .data$FRDM.p)) %>%
    mutate(signif_lvl = ifelse(FRDM.p < 0.05, "*", ""))
  text(x = max(profile_boxplot_data$Effect_size, na.rm = T)*1.02 , 
       y = c(0.4, 0.28),
       label = label_signif_03_10$signif_lvl,
       adj=0, cex=2)
  
  mtext("2003 - 2010", side = 4, cex = 2, line = 3)
  
  
  boxplot_data_10_15 <- profile_boxplot_data %>%
    filter(Period == "d2010.2015") %>%
    droplevels()
  
  plot(x=0, xlim=range_x, ylim=range_y, axes = T, las = 1, col = "white",  yaxt="n", # to remove numbers of y axis
       ylab = "", xlab = label_boxplot[p], las = 1, cex.axis=1.5, cex.lab=2)
  axis(side = 2, at = 0.5, labels = "O-layer", las = 1, cex.axis=1.5, cex.lab=2)
  abline(v=0)
  
  boxplot(data = boxplot_data_10_15,
          Effect_size ~ Treatment,   
          add = TRUE, horizontal = T, boxwex = 0.10, col = box_colors, axes = FALSE,
          at = c(0.4, 0.28) )
  
  legend("top", 
         legend = c("Control", "Limed"),
         fill = box_colors,
         bty = "o", 
         ncol = 2,
         cex = 1.4)
  
  # label: significant y/n according to Freidman
  label_signif_10_15 <-  unique(select(boxplot_data_10_15, .data$Depth, .data$Treatment, .data$FRDM.p)) %>%
    mutate(signif_lvl = ifelse(FRDM.p < 0.05, "*", ""))
  text(x = max(profile_boxplot_data$Effect_size, na.rm = T)*1.02 , 
       y = c(0.4, 0.28),
       label = label_signif_10_15$signif_lvl,
       adj=0, cex=2)
  
  mtext("2010 - 2015", side = 4, cex = 2, line = 3)
  
  dev.off()  #end OL_stock plot
    

  # 4: compose the Effects Size table
  effect_size_table_year <- calc_effects_table_year(effect_size_data_year)
  effect_size_table_year_pval <- left_join(effect_size_table_year, parameters_year_friedman, by=c("Depth","Treatment","Period","Parameter"))
  effect_size_table_year_pval <- effect_size_table_year_pval[c("Parameter","Unit","Depth","Period","Treatment","ES_mean","ES_sd","ES_N_minus","ES_N_plus","ES_range","FRDM.p")]

  write.csv2(effect_size_table_year_pval,
             paste0("Effect_size_by_year_Group-",i,".csv"),
             col.names= T, row.names = F)
  
}



########################################
# Plots
########################################
#######################
#### TS boxplots ####
# Parameters: pH (H2O), pH(KCl), BS, Ctot, Ntot

param_boxplot <- c("Carbon", "Nitrogen", "BS", "pH_H2O", "pH_KCl", "OL_stock")
param_min <- c(0, 0, 0, 2.5, 2, 0)
label_boxplot <- c("C (g/kg)","N (g/kg)", "Base saturation (%)", expression('pH (H' [2] * 'O)'), "pH (KCl)", "O-layer stock (Mg/ha)") 

# select data
select_boxplot_data <- function(data) {
  output <- data %>%
    ungroup() %>%
    filter(Name %in% site_groups[[i]]) %>%
    filter(Parameter %in% param_boxplot[p])  %>%
    droplevels()
  return(output)
}


for (i in c(1:3)) {    # start site groups
  # i <- 2
  
  for (p in c(1:5)) {    # start parameters, without OL_stock
    # p <- 4
    
   hum_boxplot_data <- select_boxplot_data(humus_historic_long)
   bod_boxplot_data <- select_boxplot_data(boden_historic_long)
   
   profile_boxplot_data <- bind_rows(hum_boxplot_data, bod_boxplot_data) %>%
     arrange(factor(Depth, levels = c("O-layer","0-5cm","5-10cm","10-30cm","30-60cm")))

   range_x <- c(param_min[p], max(profile_boxplot_data$Measurement, na.rm = T)*1.08 )    # Parameter values range
   range_y <- range(0.5, 6)  # Profile depth
   
   
   boxplot_data_Control <- profile_boxplot_data %>%
     filter(!(is.na(Measurement)))  %>%
     filter(Treatment == "Control") %>%
     droplevels()
   
   pdf(file = paste0("Boxplots_Group-", i, "_", param_boxplot[p], ".pdf"),
       family="Helvetica-Narrow", 
       width = 6,
       height = 12,
       pointsize = 10
   )
   
   par(mar = c(5,6,2,6), mfrow = c(2,1))
   
   box_colors_c <- c(rgb(204,230,255, maxColorValue = 255), rgb(128,191,255, maxColorValue = 255), rgb(51,153,255, maxColorValue = 255))

   plot(x=0, xlim=range_x, ylim=range_y, axes = T, las = 1, col = "white",  yaxt="n", # to remove numbers of y axis
        ylab = "", xlab = label_boxplot[p], las = 1, cex.axis=1.5, cex.lab=2)
   axis(side = 2, at = c(5,4,3,2,1), labels = c("O-layer","0-5cm","5-10cm","10-30cm","30-60cm"), las = 1, cex.axis=1.5, cex.lab=2)

   if (p != 3) {   # when Base saturation, no data for Humus layer
   boxplot(data = boxplot_data_Control [boxplot_data_Control$Depth == "O-layer",] ,
           Measurement ~ Year,  
           add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors_c, axes = FALSE,
           at = c(5.2,5.0,4.8))
   }
   
   boxplot(data = boxplot_data_Control [boxplot_data_Control$Depth == "0-5cm",] ,
           Measurement ~ Year,  
           add = TRUE, horizontal = T, boxwex = 0.18, axes = FALSE,
           col = box_colors_c,
           at = c(4.2, 4.0, 3.8) )
   
   boxplot(data = boxplot_data_Control [boxplot_data_Control$Depth == "5-10cm",] ,
           Measurement ~ Year,  
           add = TRUE, horizontal = T, boxwex = 0.18, axes = FALSE,
           col = box_colors_c,
           at = c(3.2, 3.0, 2.8) )
   
   boxplot(data = boxplot_data_Control [boxplot_data_Control$Depth == "10-30cm",] ,
           Measurement ~ Year,  
           add = TRUE, horizontal = T, boxwex = 0.18, axes = FALSE,
           col = box_colors_c,
           at = c(2.2, 2.0, 1.8) )
   
   boxplot(data = boxplot_data_Control [boxplot_data_Control$Depth == "30-60cm",] ,
           Measurement ~ Year,  
           add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors_c, axes = FALSE,
           at = c(1.2, 1.0, 0.8))
   
   # add respective year as text on left side
   obs_years <- sort(unique(profile_boxplot_data$Year))
   
   legend("top", 
            legend = c("2003", "2010", "2015"),
            fill = box_colors_c,
            bty = "o", 
            ncol = 3,
            cex = 1.4)
    
   # add signif y/n of year
   year_result <- friedman_by_year[[i]] %>%
     filter(Treatment == "Control") %>%
     filter(Parameter %in% param_boxplot[p])  %>%
     droplevels() %>%
     select(-c("friedman.p", "posthoc_03.15")) %>%
     gather(key = "Period", value = "FRDM.p", -c("Depth", "Treatment", "Parameter"), na.rm = T) %>%
     mutate(Year = ifelse(Period == "posthoc_03.10", "2010", "2015") )
   
   label_signif_FRDM <- left_join(unique(select(boxplot_data_Control, .data$Parameter, .data$Depth, .data$Year)), 
                                  year_result, by=c("Parameter", "Depth", "Year")) %>%
     arrange(factor(Year, levels= c("2003", "2010","2015"))) %>%
     arrange(factor(Depth, levels = c("O-layer","0-5cm","5-10cm","10-30cm","30-60cm") )) %>%
     mutate(signif_lvl_FRDM = ifelse(FRDM.p < 0.05 & !is.na(FRDM.p), "*", ""))
   
   if (p == 3) { # Base saturation no data for Humus layer
       text(x = max(profile_boxplot_data$Measurement, na.rm = T)*1.06 , 
            y = c(4.2, 4.0, 3.8, 3.2, 3.0, 2.8, 2.2, 2.0, 1.8, 1.2, 1.0, 0.8),
            label = label_signif_FRDM$signif_lvl_FRDM,
            adj=0, cex=2.4)
     } else {
       text(x = max(profile_boxplot_data$Measurement, na.rm = T)*1.06 , 
            y = c(5.2, 5.0, 4.8, 4.2, 4.0, 3.8, 3.2, 3.0, 2.8, 2.2, 2.0, 1.8, 1.2, 1.0, 0.8),
            label = label_signif_FRDM$signif_lvl_FRDM,
            adj=0, cex=2.4)
     }
   
    mtext("Control", side = 4, cex = 2.2, line = 3)
    
    
    
    boxplot_data_Limed <- profile_boxplot_data %>%
      filter(Treatment == "Limed") %>%
      droplevels()
    
    box_colors_l <- c(rgb(217,179,255, maxColorValue = 255), rgb(191,128,255, maxColorValue = 255), rgb(140,26,255, maxColorValue = 255))

    plot(x=0, xlim=range_x, ylim=range_y, axes = T, las = 1, col = "white",  yaxt="n", # to remove numbers of y axis
         ylab = "", xlab = label_boxplot[p], las = 1, cex.axis=1.5, cex.lab=2)
    axis(side = 2, at = c(5,4,3,2,1), labels = c("O-layer","0-5cm","5-10cm","10-30cm","30-60cm"), 
         las = 1, cex.axis=1.5, cex.lab=2)
    
    if (p != 3) {   # when Base saturation, no data for Humus layer
    boxplot(data = boxplot_data_Limed [boxplot_data_Limed$Depth == "O-layer",] ,
            Measurement ~ Year,  
            add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors_l, axes = FALSE,
            at = c(5.2,5.0,4.8))
    }
    
    boxplot(data = boxplot_data_Limed [boxplot_data_Limed$Depth == "0-5cm",] ,
            Measurement ~ Year,  
            add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors_l, axes = FALSE,
            at = c(4.2, 4.0, 3.8))
    boxplot(data = boxplot_data_Limed [boxplot_data_Limed$Depth == "5-10cm",] ,
            Measurement ~ Year,  
            add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors_l, axes = FALSE,
            at = c(3.2, 3.0, 2.8))
    boxplot(data = boxplot_data_Limed [boxplot_data_Limed$Depth == "10-30cm",] ,
            Measurement ~ Year,  
            add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors_l, axes = FALSE,
            at = c(2.2, 2.0, 1.8))
    boxplot(data = boxplot_data_Limed [boxplot_data_Limed$Depth == "30-60cm",] ,
            Measurement ~ Year,  
            add = TRUE, horizontal = T, boxwex = 0.18, col = box_colors_l, axes = FALSE,
            at = c(1.2, 1.0, 0.8))
    
    # add respective year as text on left side
    # if (p != 4) { 
    #   text(x = max(profile_boxplot_data$Measurement, na.rm = T)*1.1 , 
    #        y = c(5.2, 5.0, 4.8, 4.2, 4.0, 3.8, 3.2, 3.0, 2.8, 2.2, 2.0, 1.8, 1.2, 1.0, 0.8),
    #        label = c(obs_years[-1], obs_years[-1], obs_years[-1], obs_years[-1], obs_years[-1]),
    #        adj=0, cex=1)
    # } else {     # when Base saturation, no data for Humus layer
    #   text(x = max(profile_boxplot_data$Measurement, na.rm = T)*1.1 , 
    #        y = c(4.2, 4.0, 3.8, 3.2, 3.0, 2.8, 2.2, 2.0, 1.8, 1.2, 1.0, 0.8),
    #        label = c(obs_years[-1], obs_years[-1], obs_years[-1], obs_years[-1]),
    #        adj=0, cex=1)
    # }
    legend("top", 
           legend = c("2003", "2010", "2015"),
           fill = box_colors_l,
           bty = "o", 
           ncol = 3,
           cex = 1.4)
    
    # add signif y/n of year
    FRDM_result <- friedman_by_year[[i]] %>%
      filter(Treatment == "Limed") %>%
      filter(Parameter %in% param_boxplot[p])  %>%
      droplevels() %>%
      select(-c("friedman.p", "posthoc_03.15")) %>%
      gather(key = "Period", value = "FRDM.p", -c("Depth", "Treatment", "Parameter"), na.rm = T) %>%
      mutate(Year = ifelse(Period == "posthoc_03.10", "2010", "2015") )
    
    label_signif_FRDM <- left_join(unique(select(boxplot_data_Limed, .data$Parameter, .data$Depth, .data$Year)), 
                                   FRDM_result, by=c("Parameter", "Depth", "Year")) %>%
      arrange(factor(Year, levels= c("2003", "2010","2015"))) %>%
      arrange(factor(Depth, levels = c("O-layer","0-5cm","5-10cm","10-30cm","30-60cm") )) %>%
      mutate(signif_lvl_FRDM = ifelse(FRDM.p < 0.05, "*", ""))
    
    if (p != 3) { 
      text(x = max(profile_boxplot_data$Measurement, na.rm = T)*1.06 , 
           y = c(5.2, 5.0, 4.8, 4.2, 4.0, 3.8, 3.2, 3.0, 2.8, 2.2, 2.0, 1.8, 1.2, 1.0, 0.8),
           label = label_signif_FRDM$signif_lvl_FRDM,
           adj=0, cex=2.4)
    } else {     # when Base saturation, no data for Humus layer
      text(x = max(profile_boxplot_data$Measurement, na.rm = T)*1.06 , 
           y = c(4.2, 4.0, 3.8, 3.2, 3.0, 2.8, 2.2, 2.0, 1.8, 1.2, 1.0, 0.8),
           label = label_signif_FRDM$signif_lvl_FRDM,
           adj=0, cex=2.4)
    }
    
    
    # add signif y/n of treatment
    MWU_result <- MWU_by_treatment[[i]] %>%
      filter(Parameter %in% param_boxplot[p])  %>%
      droplevels()
    
    label_signif_MWU <- left_join(unique(select(boxplot_data_Limed, .data$Parameter, .data$Depth, .data$Year)), 
                                  MWU_result, by=c("Parameter", "Depth", "Year")) %>%
      arrange(factor(Year, levels= c("2003", "2010","2015"))) %>%
      arrange(factor(Depth, levels = c("O-layer","0-5cm","5-10cm","10-30cm","30-60cm") )) %>%
      mutate(signif_lvl_mwu = ifelse(mwu.p < 0.05, "#", ""))
    
    if (p != 3) { 
      text(x = max(profile_boxplot_data$Measurement, na.rm = T)*1.02 , 
           y = c(5.2, 5.0, 4.8, 4.2, 4.0, 3.8, 3.2, 3.0, 2.8, 2.2, 2.0, 1.8, 1.2, 1.0, 0.8),
           label = label_signif_MWU$signif_lvl_mwu,
           adj=0, cex=1.5)
    } else {     # when Base saturation, no data for Humus layer
      text(x = max(profile_boxplot_data$Measurement, na.rm = T)*1.02 , 
           y = c(4.2, 4.0, 3.8, 3.2, 3.0, 2.8, 2.2, 2.0, 1.8, 1.2, 1.0, 0.8),
           label = label_signif_MWU$signif_lvl_mwu,
           adj=0, cex=1.5)
    }
    
    mtext("Limed", side = 4, cex = 2.2, line = 3)
    
    dev.off()
    
  } # end parameter
  
  p <- 6 #begin OL_stock plot
  
  hum_boxplot_data <- select_boxplot_data(humus_historic_long)
  bod_boxplot_data <- select_boxplot_data(boden_historic_long)
  
  profile_boxplot_data <- bind_rows(hum_boxplot_data, bod_boxplot_data)
  
  range_x <- c(param_min[p], max(profile_boxplot_data$Measurement, na.rm = T)*1.08 )    # Parameter values range
  range_y <- range(0, 1)  # Profile depth
  
  pdf(file = paste0("Boxplots_Group-", i, "_", param_boxplot[p], ".pdf"),
      family="Helvetica-Narrow", 
      width = 6,
      height = 5,
      pointsize = 10
  )
  
  par(mar = c(5,6,2,6), mfrow = c(2,1))
  
  box_colors_c <- c(rgb(204,230,255, maxColorValue = 255), rgb(128,191,255, maxColorValue = 255), rgb(51,153,255, maxColorValue = 255))
  
  boxplot_data_Control <- profile_boxplot_data %>%
    filter(!(is.na(Measurement)))  %>%
    filter(Treatment == "Control") %>%
    droplevels()
  
  plot(x=0, xlim=range_x, ylim=range_y, axes = T, las = 1, col = "white",  yaxt="n", # to remove numbers of y axis
       ylab = "", xlab = label_boxplot[p], las = 1, cex.axis=1.5, cex.lab=2)
  axis(side = 2, at = 0.5, labels = "O-layer", las = 1, cex.axis=1.5, cex.lab=2)
  
  boxplot(data = boxplot_data_Control,
          Measurement ~ Year,  
          add = TRUE, horizontal = T, boxwex = 0.10, axes = FALSE,
          col = box_colors_c,
          at = c(0.5, 0.38, 0.26))
  
  obs_years <- sort(unique(profile_boxplot_data$Year))
  
  legend("top", 
         legend = c("2003", "2010", "2015"),
         fill = box_colors_c,
         bty = "o", 
         ncol = 3,
         cex = 1.4)
  
  year_result <- friedman_by_year[[i]] %>%
    filter(Treatment == "Control") %>%
    filter(Parameter %in% param_boxplot[p])  %>%
    droplevels() %>%
    select(-c("friedman.p", "posthoc_03.15")) %>%
    gather(key = "Period", value = "FRDM.p", -c("Depth", "Treatment", "Parameter"), na.rm = T) %>%
    mutate(Year = ifelse(Period == "posthoc_03.10", "2010", "2015") )
  
  label_signif_FRDM <- left_join(unique(select(boxplot_data_Control, .data$Parameter, .data$Depth, .data$Year)), 
                                 year_result, by=c("Parameter", "Depth", "Year")) %>%
    arrange(factor(Year, levels= c("2003", "2010","2015"))) %>%
    mutate(signif_lvl_FRDM = ifelse(FRDM.p < 0.05 & !is.na(FRDM.p), "*", ""))
  
  text(x = max(profile_boxplot_data$Measurement, na.rm = T)*1.06 , 
       y = c(0.5, 0.38, 0.26),
       label = label_signif_FRDM$signif_lvl_FRDM,
       adj=0, cex=2.4)
  
  mtext("Control", side = 4, cex = 2, line = 3)
  
  
  boxplot_data_Limed <- profile_boxplot_data %>%
    filter(Treatment == "Limed") %>%
    droplevels()
  
  box_colors_l <- c(rgb(217,179,255, maxColorValue = 255), rgb(191,128,255, maxColorValue = 255), rgb(140,26,255, maxColorValue = 255))
  
  plot(x=0, xlim=range_x, ylim=range_y, axes = T, las = 1, col = "white",  yaxt="n", # to remove numbers of y axis
       ylab = "", xlab = label_boxplot[p], las = 1, cex.axis=1.5, cex.lab=2)
  axis(side = 2, at = 0.5, labels = "O-layer", las = 1, cex.axis=1.5, cex.lab=2)
  
  boxplot(data = boxplot_data_Limed,
          Measurement ~ Year,  
          add = TRUE, horizontal = T, boxwex = 0.10, col = box_colors_l, axes = FALSE,
          at = c(0.5, 0.38, 0.26) )
  
  legend("top", 
         legend = c("2003", "2010", "2015"),
         fill = box_colors_l,
         bty = "o", 
         ncol = 3,
         cex = 1.4)
  
  # add signif y/n of year
  FRDM_result <- friedman_by_year[[i]] %>%
    filter(Treatment == "Limed") %>%
    filter(Parameter %in% param_boxplot[p])  %>%
    droplevels() %>%
    select(-c("friedman.p", "posthoc_03.15")) %>%
    gather(key = "Period", value = "FRDM.p", -c("Depth", "Treatment", "Parameter"), na.rm = T) %>%
    mutate(Year = ifelse(Period == "posthoc_03.10", "2010", "2015") )
  
  label_signif_FRDM <- left_join(unique(select(boxplot_data_Limed, .data$Parameter, .data$Depth, .data$Year)), 
                                 FRDM_result, by=c("Parameter", "Depth", "Year")) %>%
    arrange(factor(Year, levels= c("2003", "2010","2015"))) %>%
    mutate(signif_lvl_FRDM = ifelse(FRDM.p < 0.05, "*", ""))
  
  text(x = max(profile_boxplot_data$Measurement, na.rm = T)*1.06 , 
       y = c(0.5, 0.38, 0.26),
       label = label_signif_FRDM$signif_lvl_FRDM,
       adj=0, cex=2.4)
  
  # add signif y/n of treatment
  MWU_result <- MWU_by_treatment[[i]] %>%
    filter(Parameter %in% param_boxplot[p])  %>%
    droplevels()
  
  label_signif_MWU <- left_join(unique(select(boxplot_data_Limed, .data$Parameter, .data$Depth, .data$Year)), 
                                MWU_result, by=c("Parameter", "Depth", "Year")) %>%
    arrange(factor(Year, levels= c("2003", "2010","2015"))) %>%
    mutate(signif_lvl_mwu = ifelse(mwu.p < 0.05, "#", ""))
  
  text(x = max(profile_boxplot_data$Measurement, na.rm = T)*1.02 , 
       y = c(0.5, 0.38, 0.26),
       label = label_signif_MWU$signif_lvl_mwu,
       adj=0, cex=1.5)
  
  mtext("Limed", side = 4, cex = 2.2, line = 3)
  
  dev.off()  #end OL_stock plot
  
} #end group


#######################
##### Stacked Barplots of CEC ions ####
Param_cec_barplot <- c("Ca..","Mg..","K.","Na.","Al...","Fe...","Mn..","H.")
cec_label <- expression(paste("CEC (", mu, mol[c], "/g)"))

#obs_years <- sort(unique(boden_historic_long$Year))

cec_colors <- c("steelblue", "steelblue2", "steelblue4", "steelblue1", "red", "orange", "yellow", "green")


# calculate mean concentrations of CEC ions
calc_cec_barplot <- function(data) {
  output <- data %>%
    ungroup() %>%
    filter(Name %in% site_groups[[i]]) %>%
    filter(Parameter %in% Param_cec_barplot)  %>%
    droplevels()  %>%
    group_by(Year, Treatment, Depth, Parameter) %>%
    summarise(Means = round(mean(Measurement, na.rm = TRUE), 2))
  return(output)
}

for (i in c(1:3)) { # start site groups
  # i <- 1
  
  data_cec <- calc_cec_barplot(boden_historic_long)
  
  cec_max <- boden_historic_long %>%
    filter(Name %in% site_groups[[i]]) %>%
    filter(Parameter == "CEC") %>%
    group_by(Year, Treatment, Depth) %>%
    summarise(Mean_ake = mean(Measurement, na.rm = TRUE)) %>%
    ungroup() %>%
    summarise(max_ake = max(Mean_ake))
  
  cec_max <- 220
  
  # data_cec_check <- calc_cec_check(data_cec)
  # data_cec_orig <- calc_cec_orig(boden_historic_long)
  
  pdf(file = paste0("CEC_barplots_Group-", i, ".pdf"),
      family="Helvetica-Narrow", 
      width = 6,
      height = 12,
      pointsize = 10
  )
  
  par(mar = c(5,6,2,6), mfrow = c(2,1))
  
  col_years = c("2015","2010","2003")
      
      barplot_cec_data_n <- data_cec %>%
        ungroup() %>%
        filter(Treatment == "Control") %>%
        mutate(Year_a = ifelse(Year == "2003", "c",
                                      ifelse(Year == "2010", "b", "a"))) %>%
        mutate(Depth_1 = ifelse(Depth == "0-5cm", "4", 
                               ifelse(Depth == "5-10cm", "3",
                                      ifelse(Depth == "10-30cm", "2", "1")))) %>%
        unite("bars", Depth_1, Year_a, sep = "", remove = T) %>%
        select(bars, Parameter, Means)  %>%
        spread(bars, Means) %>%
        arrange(factor(Parameter, levels=Param_cec_barplot))
      
      bp <- barplot(as.matrix(barplot_cec_data_n[,-1]),
                    beside = F,
                    horiz = T,
                    space = c(0.7,0.7,0.7, 2,0.7,0.7, 2,0.7,0.7, 2,0.7),
                    las=1, cex.axis=1.5, cex.lab=2, cex = 1.5,
                    xlab =  expression(paste("CEC (", mu, mol[c], "/g)")),
                    names.arg = c("","30-60cm","", "","10-30cm","", "","5-10cm","","","0-5cm",""),
                    xlim = range(c(0, cec_max*1.4)),
                    col = cec_colors
                    )
      text(cec_max*1.3, bp,
           c(col_years[-4], col_years, col_years, col_years),
           cex=1.5)
      
      # add signif y/n of year: Ake
      FRDM_result <- friedman_by_year[[i]] %>%
        filter(Treatment == "Control")
      
      year_result <- FRDM_result %>%
        filter(Parameter == "CEC")  %>%
        droplevels() %>%
        select(-c("friedman.p", "posthoc_03.15")) %>%
        gather(key = "Period", value = "FRDM.p", -c("Depth", "Treatment", "Parameter"), na.rm = T) %>%
        mutate(Year = ifelse(Period == "posthoc_03.10", "2010", "2015") ) %>%
        arrange(factor(Year, levels= c("2003", "2010","2015"))) %>%
        arrange(factor(Depth, levels = c("0-5cm","5-10cm","10-30cm","30-60cm") )) %>%
        mutate(signif_lvl_FRDM = ifelse(FRDM.p < 0.05 & !is.na(FRDM.p), "*", ""))
      
      text(cec_max*1.2, bp[c(1,2, 4,5,6, 8,9,10, 12,13,14)],
           rev(year_result$signif_lvl_FRDM), #c(1:11)
           cex=2.4)

      legend(cec_max*0.4, bp[4]-1, 
             legend = c("Ca", "Mg", "K", "Na", "Al", "Fe", "Mn", "H"),
             fill = cec_colors,
             bty = "n", 
             ncol = 3,
             cex = 1.4)

       mtext("Control", side = 4, cex = 2.2, line = 3)
       

      barplot_cec_data_k <- data_cec %>%
        ungroup() %>%
        filter(Treatment == "Limed") %>%
        mutate(Year_a = ifelse(Year == "2003", "c",
                                      ifelse(Year == "2010", "b", "a"))) %>%
        mutate(Depth_1 = ifelse(Depth == "0-5cm", "4", 
                                   ifelse(Depth == "5-10cm", "3",
                                          ifelse(Depth == "10-30cm", "2", "1")))) %>%
        unite("bars", Depth_1, Year_a, sep = "", remove = T) %>%
        select(bars, Parameter, Means)  %>%
        spread(bars, Means) %>%
        arrange(factor(Parameter, levels=Param_cec_barplot))
      
      bp <- barplot(as.matrix(barplot_cec_data_k[,-1]),
                    beside = F,
                    horiz = T,
                    space = c(0.7,0.7,0.7,2, 0.7,0.7,2, 0.7,0.7,2, 0.7,0.7),
                    las=1, cex.axis=1.5, cex.lab=2, cex = 1.5,
                    xlab =  expression(paste("CEC (", mu, mol[c], "/g)")),
                    names.arg = c("","30-60cm","", "","10-30cm","", "","5-10cm","", "","0-5cm",""),
                    xlim = range(c(0, cec_max*1.4)),
                    col = cec_colors
      )
      text(cec_max*1.3, bp,
           c(col_years[-4], col_years[-4], col_years[-4], col_years[-4]),
           cex=1.5)
      
      # add signif y/n of year: Ake
      FRDM_result <- friedman_by_year[[i]] %>%
        filter(Treatment == "Limed") %>%
        filter(Parameter == "CEC")  %>%
        droplevels() %>%
        select(-c("friedman.p", "posthoc_03.15")) %>%
        gather(key = "Period", value = "FRDM.p", -c("Depth", "Treatment", "Parameter"), na.rm = T) %>%
        mutate(Year = ifelse(Period == "posthoc_03.10", "2010", "2015") ) %>%
        arrange(factor(Year, levels= c("2010","2015"))) %>%
        arrange(factor(Depth, levels = c("0-5cm","5-10cm","10-30cm","30-60cm") )) %>%
        mutate(signif_lvl_FRDM = ifelse(FRDM.p < 0.05 & !is.na(FRDM.p), "*", ""))
      
      text(cec_max*1.2, bp[c(1,2, 4,5, 7,8, 10,11)],
           rev(FRDM_result$signif_lvl_FRDM),
           cex=2.4)
      
      # add signif y/n of liming: Ake
      MWU_result <- MWU_by_treatment[[i]] %>%
        filter(Parameter == "CEC")  %>%
        arrange(factor(Year, levels= c("2003", "2010","2015"))) %>%
        arrange(factor(Depth, levels = c("0-5cm","5-10cm","10-30cm","30-60cm") )) %>%
        mutate(signif_lvl_mwu = ifelse(mwu.p < 0.05, "#", ""))
      
      text(cec_max*1.1, bp,
           rev(MWU_result$signif_lvl_mwu),
           cex=1.5)
      
      
      legend(cec_max*0.4, bp[3]+0.75, 
             legend = c("Ca", "Mg", "K", "Na", "Al", "Fe", "Mn", "H"),
             fill = cec_colors,
             bty = "n", 
             ncol = 3,
             cex = 1.4)
      
      mtext("Limed", side = 4, cex = 2.2, line = 3)

  dev.off()
  
} # end groups


#######################





